# OCDS Cardinal

[![crates.io Version](https://img.shields.io/crates/v/ocdscardinal.svg)](https://crates.io/crates/ocdscardinal)
[![Build Status](https://github.com/open-contracting/cardinal-rs/actions/workflows/ci.yml/badge.svg)](https://github.com/open-contracting/cardinal-rs/actions/workflows/ci.yml)
[![Coverage Status](https://codecov.io/github/open-contracting/cardinal-rs/graph/badge.svg)](https://codecov.io/github/open-contracting/cardinal-rs)

Measure red flags and procurement indicators using OCDS data.

If you are viewing this on GitHub, crates.io or similar, open the [full documentation](https://cardinal.readthedocs.io/) for additional details.
